@@ -2,13 +2,13 @@ import time
 import math
 
 SPINNER_FRAMES = ["\u25DC ", " \u25DD", " \u25DE", "\u25DF "]
-LOADING_UNIT = "\u25AF"
 
 
 def bar(current_progress: int,
         total=100,
-        bar_length=25,
-        show_percentage=False):
+        bar_length=10,
+        show_percentage=False,
+        icon='\u2588'):
     '''
     Prints out a loading bar with the given loading progression
     based on `current_progress` and `total`. The with of the loading bar 
@@ -19,9 +19,9 @@ def bar(current_progress: int,
     percentage = current_progress / (total / 100)
     q = math.floor(percentage / (100 / bar_length))
     remaining = bar_length - q
-    bar = f'[{LOADING_UNIT * q}{" "*remaining}]'
+    bar = f'{icon * q}{" "*remaining}'
     if show_percentage:
-        print(f'\r{bar} {percentage} %', end='')
+        print(f'\r{bar} {round(percentage, 1)} %', end='')
     else:
         print(f'\r{bar}', end='')
 
